@@ -25,6 +25,8 @@ polynomial.sensitivity <- function( data, model, sa.samp = 1000 ) {
   sa <- cbind( mainEffect( metamodel ), totEffect( metamodel ) - mainEffect( metamodel ) )
   rownames( sa ) <- colnames( data$doe )
   colnames( sa ) <- c( "Direct effects", "Interactions" )
+  sa <- as.data.frame( sa )
+  sa <- sa[ order( - rowSums( sa, na.rm = TRUE ) ), ]
 
   max.index <- function( x, pos = 1 ) as.integer( sapply( sort( x, index.return = TRUE ),
                                                           `[`, length( x ) - pos + 1 )[ 2 ] )
